Clouvel Pro Admin

Active Licenses
-
Total Licenses
-
Refunded
-
Blocked
-
24h API Calls
-
24h Anomalies
-

## Recent Activity

Time | Event | License | Details
--- | --- | --- | ---
Connect to load data...

## License Management

License Key | Tier | Status | Machines | Last Active | Actions
--- | --- | --- | --- | --- | ---
Connect to load data...

## Refund History

Date | License Key | Order ID | Reason
--- | --- | --- | ---
Connect to load data...

## Audit Log

Time | Event Type | License | IP | Details
--- | --- | --- | --- | ---
Connect to load data...

Suspicion Level 1
-
Suspicion Level 2
-
Suspicion Level 3
-
Sharing Suspects
-

## Anomaly Detection

License | Suspicion Score | Countries | Machines | Actions
--- | --- | --- | --- | ---
Connect to load data...

### Block License

### Unblock License